@@ -551,3 +551,46 @@ def hrs_compare_excel_data(username, password, server_name, share_name, from_dat
             check_result_df[column_name] = check_result_df[column_name].astype(str).str.strip()
 
     return check_result_df
+
+
+def hrs_transpose_excel_data(username, password, server_name, share_name, from_data, config_folder_path, config_file_name, config_sheet_name, port=445):
+    """ This function compares rehiring data from the last two weeks and returns the differences.
+
+    Args:
+        username(str): The username for SMB authentication.
+        password(str): The password for SMB authentication.
+        server_name(str): The name of the SMB server.
+        share_name(str): The name of the SMB share.
+        from_data(pd.DataFrame): The DataFrame containing the original data to compare from.
+        config_folder_path(str): The path to the folder containing the configuration file for column mappings.
+        config_file_name(str): The name of the configuration file containing the column mappings.
+        config_sheet_name(str): The name of the sheet in the configuration file.
+        port(int): The port number for the SMB connection.
+    """
+    transpose_data_dict = OrderedDict()
+
+    config_file_path = os.path.join(config_folder_path, config_file_name)
+    config_file_obj = smb_load_file_obj(username, password, server_name, share_name, config_file_path, port)
+    config_data = pd.read_excel(config_file_obj, sheet_name=config_sheet_name, dtype={'Source Column Name': str, 'New Column Name': str, 'Column Order': int})
+    config_data.fillna('', inplace=True)
+
+    column_data = config_data.copy()
+    column_data = column_data.drop_duplicates(subset=['New Column Name'])
+    new_column_name_list = column_data['New Column Name'].tolist()
+    config_group_data = config_data.groupby(by=['New Column Name'])
+
+    if not from_data.empty:
+        for new_column_name_tuple, group_data in config_group_data:
+            new_column_name_tuple: tuple
+            new_column_name = new_column_name_tuple[0]
+            group_data = group_data.sort_values(by=['Column Order'])
+            source_column_list = group_data['Source Column Name'].tolist()
+            for source_column in source_column_list:
+                source_column_data = from_data[source_column].tolist()
+                transpose_data_dict.setdefault(new_column_name, []).extend(source_column_data)
+    else:
+        for new_column_name, group_data in config_group_data:
+            transpose_data_dict[new_column_name] = []
+
+    transpose_data_df = pd.DataFrame(transpose_data_dict, columns=new_column_name_list)
+    return transpose_data_df
