@@ -184,6 +184,8 @@ class MiniRpaManager(MiniRpaFunction):
                     sap_automation.download_excel_by_menu_click(sap_operation_dict['file_name'])
                 elif function_name == 'download_excel_by_views_button_click':
                     sap_automation.download_excel_by_views_button_click(sap_operation_dict['file_name'])
+                elif function_name == 'download_excel_by_export_button_click':
+                    sap_automation.download_excel_by_export_button_click(sap_operation_dict['file_name'])
                 elif function_name == 'select_layout_before_download_excel':
                     sap_automation.select_layout_before_download_excel(layout_name, shortcut_list)
                 elif function_name == 'select_se16_layout_before_download_excel':
@@ -194,7 +196,7 @@ class MiniRpaManager(MiniRpaFunction):
                     sap_automation.click_button_by_mouse(sap_operation_dict['button_title'])
                 elif function_name == 'click_radio_checkbox':
                     sap_automation.click_radio_checkbox(sap_operation_dict['radio_checkbox_title'])
-                elif function_name=='click_radio_checkbox_by_mouse':
+                elif function_name == 'click_radio_checkbox_by_mouse':
                     sap_automation.click_radio_checkbox_by_mouse(sap_operation_dict['radio_checkbox_title'])
                 elif function_name == 'input_reporting_period':
                     sap_automation.input_reporting_period(sap_operation_dict['reporting_period_name'], sap_operation_dict['reporting_start_date'],
@@ -206,18 +208,29 @@ class MiniRpaManager(MiniRpaFunction):
                      query_value_columns,
                      file_name,
                      sheet_name,
-                     tab_index) = (sap_operation_dict['query_button_index'],
-                                   sap_operation_dict['query_value_input_method'],
-                                   sap_operation_dict['remote_folder_path'],
-                                   sap_operation_dict['query_value_columns'],
-                                   sap_operation_dict['file_name'],
-                                   sap_operation_dict['sheet_name'],
-                                   sap_operation_dict['tab_index'])
+                     tab_index,
+                     has_range,
+                     start_range,
+                     end_range
+
+                     ) = (sap_operation_dict['query_button_index'],
+                          sap_operation_dict['query_value_input_method'],
+                          sap_operation_dict['remote_folder_path'],
+                          sap_operation_dict['query_value_columns'],
+                          sap_operation_dict['file_name'],
+                          sap_operation_dict['sheet_name'],
+                          sap_operation_dict['tab_index'],
+                          sap_operation_dict.get('has_range', False),
+                          sap_operation_dict.get('start_range', None),
+                          sap_operation_dict.get('end_range', None),
+                          )
                     query_value_columns = query_value_columns.split(',') if query_value_columns else None
                     sap_automation.input_query_values_from_existed_data(int(query_button_index), query_value_input_method, remote_folder_path, query_value_columns, file_name,
-                                                                        sheet_name, int(tab_index))
+                                                                        sheet_name, int(tab_index), has_range, start_range, end_range)
                 elif function_name == 'find_variant_by_name':
                     sap_automation.find_variant_by_name(sap_operation_dict['variant_name'])
+                elif function_name == 'find_abap_variant_by_name':
+                    sap_automation.find_abap_variant_by_name(sap_operation_dict['variant_name'])
                 elif function_name == 'find_organization_data_by_company_code':
                     sap_automation.find_organization_data_by_company_code(sap_operation_dict['company_code'])
                 elif function_name == 'back_to_home_page':
@@ -480,16 +493,17 @@ class MiniRpaManager(MiniRpaFunction):
                                                sheet_name, extract_all_pages, extract_all_tables)
             elif function_name == 'batch_save_pdf_table_into_excel':
                 (pdf_folder_path, search_key_word, page_number, table_index, first_column_name, save_column_names, excel_folder_path, excel_file_name, sheet_name,
-                 extract_all_pages,
-                 extract_all_tables, enable_pdf_history, history_folder_path) = (
+                 extract_all_pages, extract_all_tables, enable_pdf_history, history_folder_path, history_file_operation) = (
                     self.process_dict.get('pdf_folder_path', ''), self.process_dict.get('search_key_word', ''), self.process_dict.get('page_number', 1),
                     self.process_dict.get('table_index', 1), self.process_dict.get('first_column_name', ''), self.process_dict.get('save_column_names', ''),
                     self.process_dict.get('excel_folder_path', ''), self.process_dict.get('excel_file_name', ''), self.process_dict.get('sheet_name', ''),
                     self.process_dict.get('extract_all_pages', False), self.process_dict.get('extract_all_tables', False),
-                    self.process_dict.get('enable_pdf_history', False), self.process_dict.get('history_folder_path', '')
+                    self.process_dict.get('enable_pdf_history', False), self.process_dict.get('history_folder_path', ''), self.process_dict.get('history_file_operation', 'move'),
                 )
+                history_file_operation = history_file_operation if history_file_operation else 'move'
                 self.batch_save_pdf_table_into_excel(pdf_folder_path, search_key_word, page_number, table_index, first_column_name, save_column_names, excel_folder_path,
-                                                     excel_file_name, sheet_name, extract_all_pages, extract_all_tables, enable_pdf_history, history_folder_path)
+                                                     excel_file_name, sheet_name, extract_all_pages, extract_all_tables, enable_pdf_history, history_folder_path,
+                                                     history_file_operation)
             elif function_name == 'save_excel_data_into_text':
                 excel_folder_path, excel_file_name, text_folder_path, text_file_name, sheet_name, save_column_names, keep_header = (
                     self.process_dict.get('excel_folder_path', ''), self.process_dict.get('excel_file_name', ''), self.process_dict.get('text_folder_path', ''),
