@@ -422,7 +422,7 @@ class MiniRpaSapAutomation:
             self.web_rpa.input_download_excel_file_name(file_name, True, self.user_name, self.user_password, self.server_name, self.share_name, self.report_save_path)
 
     def download_excel_by_views_button_click(self, file_name):
-        """ This function is used to download Excel by menu click.
+        """ This function is used to download Excel by views button click.
 
         Args:
             file_name(str): This is the name of file
@@ -448,6 +448,30 @@ class MiniRpaSapAutomation:
             sleep(1)
             self.web_rpa.input_download_excel_file_name(file_name, True, self.user_name, self.user_password, self.server_name, self.share_name, self.report_save_path)
 
+    def download_excel_by_export_button_click(self, file_name):
+        """ This function is used to download Excel by export click.
+
+        Args:
+            file_name(str): This is the name of file
+        """
+        sleep(2)
+        self.web_rpa.wait_invisibility_of_loading_window()
+        sleep(1)
+        self.web_rpa.click_or_input_by_css_selector("div[title='Export']", 'click')
+        sleep(2)
+        self.web_rpa.move_to_and_click_element("tr[aria-label='Spreadsheet']")
+        sleep(2)
+        self.web_rpa.wait_invisibility_of_loading_window()
+        is_cancelled = self.web_rpa.input_download_excel_file_name(file_name, True, self.user_name, self.user_password, self.server_name, self.share_name, self.report_save_path)
+        if is_cancelled:
+            self.web_rpa.click_or_input_by_css_selector("div[title='Export']", 'click')
+            sleep(2)
+            self.web_rpa.move_to_and_click_element("tr[aria-label='Spreadsheet']")
+            sleep(2)
+            self.web_rpa.wait_invisibility_of_loading_window()
+            sleep(1)
+            self.web_rpa.input_download_excel_file_name(file_name, True, self.user_name, self.user_password, self.server_name, self.share_name, self.report_save_path)
+
     def download_excel_by_click_spreadsheet_button(self, spreadsheet_title, file_name):
         """ This function is used to download excel by clicking spreadsheet button.
 
@@ -598,7 +622,7 @@ class MiniRpaSapAutomation:
             sleep(1)
 
     def input_query_values_from_existed_data(self, query_button_index, query_value_input_method='local_file', remote_folder_path='', query_value_columns=None, file_name='',
-                                             sheet_name='Sheet1', tab_index=1):
+                                             sheet_name='Sheet1', tab_index=1, has_range=False, start_range=None, end_range=None):
         """ This function is used to input query values.
 
         Args:
@@ -609,12 +633,31 @@ class MiniRpaSapAutomation:
             file_name(str): This is the path of file
             sheet_name(str): This is the name of sheet
             tab_index(int): This is the index of tab
+            has_range(bool): This indicates whether to has range
+            start_range(int): This is the start range of data
+            end_range(int): This is the end range of data
         """
         if query_value_columns is None:
             query_value_columns = []
 
         is_file_exist, file_data = self.load_downloaded_excel_file(query_value_input_method, file_name, sheet_name, remote_folder_path)
         if is_file_exist:
+            if has_range and not file_data.empty:
+                start_range = abs(int(start_range)) - 1 if start_range else 0
+                end_range = abs(int(end_range)) if end_range else file_data.shape[0]
+
+                start_range = 0 if start_range < 0 else start_range
+                end_range = file_data.shape[0] if end_range > file_data.shape[0] else end_range
+
+                if start_range > end_range:
+                    start_range, end_range = end_range, start_range
+
+                file_data = file_data.iloc[start_range:end_range, :]
+                if file_data.empty:
+                    print(f'No data found in the range: {start_range} - {end_range}')
+                    self.skip_download_process = True
+                    self.back_to_home_page()
+
             if len(query_value_columns) == 2:
                 file_data['paste_column'] = file_data[query_value_columns[0]] + '\t' + file_data[query_value_columns[1]]
                 query_value_list = file_data['paste_column'].tolist()
@@ -686,6 +729,14 @@ class MiniRpaSapAutomation:
         sleep(1)
         self.web_rpa.wait_element_invisible_by_css_selector(GET_VARIANT_EXECUTE_CSS_SELECTOR)
 
+    def find_abap_variant_by_name(self, variant_name):
+        """ This function is used to find ABAP variant by name.
+
+        Args:
+            variant_name(str): This is the name of ABAP variant
+        """
+        self.web_rpa.select_abap_variant_name(variant_name)
+
     def find_organization_data_by_company_code(self, company_code):
         """ This function is used to find variant by name.
 
